@@ -1,5 +1,7 @@
 #!/bin/sh
 
+set -e
+
 # External filter binaries to install for testing.
 
 # Disable, because there are issues with the install on Travis CI.
@@ -18,3 +20,7 @@ npm install -g stylus
 npm install -g handlebars
 npm install -g typescript
 npm install -g requirejs@2.1.11
+npm install -g babel-cli@6.18.0
+# Don't install the babel-preset globally because
+# there's a bug with older verisons of node
+npm install babel-preset-es2015@6.18.0 --save
