@@ -1,13 +1,15 @@
+from webassets import six
 import contextlib
 import os
 import sys
+import re
 from itertools import takewhile
 
-from exceptions import BundleError
+from .exceptions import BundleError
 
 
 __all__ = ('md5_constructor', 'pickle', 'set', 'StringIO',
-           'common_path_prefix', 'working_directory')
+           'common_path_prefix', 'working_directory', 'is_url')
 
 
 if sys.version_info >= (2, 5):
@@ -31,10 +33,22 @@ except NameError:
 else:
     set = set
 
+
+from webassets.six import StringIO
+
+
 try:
-    from cStringIO import StringIO
-except ImportError:
-    from StringIO import StringIO
+    from urllib import parse as urlparse
+except ImportError:     # Python 2
+    import urlparse
+    import urllib
+
+def hash_func(data):
+    from .cache import make_md5
+    return make_md5(data)
+
+
+_directory_separator_re = re.compile(r"[/\\]+")
 
 
 def common_path_prefix(paths, sep=os.path.sep):
@@ -47,7 +61,10 @@ def common_path_prefix(paths, sep=os.path.sep):
     """
     def allnamesequal(name):
         return all(n==name[0] for n in name[1:])
-    bydirectorylevels = zip(*[p.split(sep) for p in paths])
+
+    # The regex splits the paths on both / and \ characters, whereas the
+    # rosettacode.org algorithm only uses os.path.sep
+    bydirectorylevels = zip(*[_directory_separator_re.split(p) for p in paths])
     return sep.join(x[0] for x in takewhile(allnamesequal, bydirectorylevels))
 
 
@@ -66,8 +83,10 @@ def working_directory(directory=None, filename=None):
         directory = os.path.dirname(filename)
     prev_cwd = os.getcwd()
     os.chdir(directory)
-    yield
-    os.chdir(prev_cwd)
+    try:
+        yield
+    finally:
+        os.chdir(prev_cwd)
 
 
 def make_option_resolver(clazz=None, attribute=None, classes=None,
@@ -120,7 +139,7 @@ def make_option_resolver(clazz=None, attribute=None, classes=None,
             return instantiate(option, env)
 
         # If it is a string
-        elif isinstance(option, basestring):
+        elif isinstance(option, six.string_types):
             parts = option.split(':', 1)
             key = parts[0]
             arg = parts[1] if len(parts) > 1 else None
@@ -173,13 +192,21 @@ def RegistryMetaclass(clazz=None, attribute=None, allow_none=True, desc=None):
 
 
 def cmp_debug_levels(level1, level2):
-    """cmp() for debug levels, returns -1, 0 or +1 indicating which debug
-    level is higher than the other one."""
-    level_ints = { False: 0, 'merge': 1, True: 2 }
+    """cmp() for debug levels, returns True if ``level1`` is higher
+    than ``level2``."""
+    level_ints = {False: 0, 'merge': 1, True: 2}
     try:
+        cmp = lambda a, b: (a > b) - (a < b)  # 333
         return cmp(level_ints[level1], level_ints[level2])
-    except KeyError, e:
+    except KeyError as e:
         # Not sure if a dependency on BundleError is proper here. Validating
         # debug values should probably be done on assign. But because this
         # needs to happen in two places (Environment and Bundle) we do it here.
         raise BundleError('Invalid debug value: %s' % e)
+
+
+def is_url(s):
+    if not isinstance(s, str):
+        return False
+    parsed = urlparse.urlsplit(s)
+    return bool(parsed.scheme and parsed.netloc) and len(parsed.scheme) > 1
