@@ -7,6 +7,7 @@ from __future__ import with_statement
 
 import copy
 from os import path
+import uuid
 try:
     from urllib.request import \
         HTTPHandler, build_opener, install_opener, addinfourl
@@ -526,12 +527,60 @@ class TestGlobbing(TempEnvironmentHelper):
                            get_all_bundle_files(self.mkbundle('*'))))
 
     def test_glob_exclude_output(self):
-        """Never include the output file in the globbinb result.
+        """Never include the output file in the globbing result.
         """
         self.create_files(['out.js'])
         assert not list(filter(lambda s: 'out.js' in s,
             get_all_bundle_files(self.mkbundle('*', output='out.js'))))
 
+    def test_glob_ordering_consistent(self):
+        """Glob results should be sorted alphabetically
+        """
+        # Create randomly named files using a UUID for both name and contents.
+        unique_names = [uuid.uuid4().hex for i in range(10)]
+        files = {}
+        for name in unique_names:
+            files[name + ".uuid"] = name
+        self.create_files(files)
+        self.mkbundle("*.uuid", output="out").build()
+        content = self.get("out").split("\n")
+        expected_output = sorted(unique_names)
+        assert content == expected_output
+
+
+class TestRemoveDuplicates(TempEnvironmentHelper):
+    default_files = {
+        'foo.js': 'foo',
+        'hubris.js': 'hubris',
+        'whimsy.js': 'whimsy'
+    }
+
+    def test_file_is_included_once(self):
+        self.mkbundle('whimsy.js', '*.js', output='out').build()
+        content = self.get('out').split('\n')
+        assert content[0] == 'whimsy'
+        remaining = content[1:]
+        remaining.sort()
+        assert remaining == ['foo', 'hubris']
+
+    def test_duplicate_nested_bundles_removed(self):
+        nested = self.mkbundle('*.js')
+        bundle = self.mkbundle(nested, nested)
+        all_files = get_all_bundle_files(bundle)
+        all_files.sort()
+        assert all_files == [self.path('foo.js'), self.path('hubris.js'),
+                             self.path('whimsy.js')]
+
+    def test_disable_remove_duplicate_option(self):
+        self.mkbundle(
+            'whimsy.js',
+            '*.js',
+            output='out',
+            remove_duplicates=False).build()
+        contents = self.get('out').split('\n')
+        contents.sort()
+        assert contents == ['foo', 'hubris', 'whimsy', 'whimsy']
+
 
 class MockHTTPHandler(HTTPHandler):
 
