@@ -1,5 +1,6 @@
 from nose.plugins.skip import SkipTest
 from webassets import Environment as AssetsEnvironment, Bundle
+from webassets.test import TempEnvironmentHelper
 
 
 try:
@@ -8,7 +9,7 @@ except ImportError:
     raise SkipTest('Jinja2 not installed')
 else:
     from jinja2 import Template, Environment as JinjaEnvironment
-    from webassets.ext.jinja2 import AssetsExtension
+    from webassets.ext.jinja2 import AssetsExtension, Jinja2Loader
 
 
 class TestTemplateTag(object):
@@ -49,9 +50,10 @@ class TestTemplateTag(object):
         AssetsExtension.BundleClass = self._old_bundle_class
         del self._old_bundle_class
 
-    def render_template(self, args, ctx={}):
+    def render_template(self, args, ctx=None):
         return self.jinja_env.from_string(
-            '{% assets '+args+' %}{{ ASSET_URL }};{% endassets %}').render(ctx)
+            '{% assets '+args+' %}{{ ASSET_URL }};{% endassets %}')\
+                .render(ctx or {})
 
     def test_reference_bundles(self):
         self.render_template('"foo_bundle", "bar_bundle"')
@@ -61,6 +63,18 @@ class TestTemplateTag(object):
         self.render_template('"file1", "file2", "file3"')
         assert self.the_bundle.contents == ('file1', 'file2', 'file3',)
 
+    def test_reference_files_list(self):
+        self.render_template('["file1", "file2", "file3"]')
+        assert self.the_bundle.contents == ('file1', 'file2', 'file3',)
+
+    def test_reference_files_tuple(self):
+        self.render_template('("file1", "file2", "file3")')
+        assert self.the_bundle.contents == ('file1', 'file2', 'file3',)
+
+    def test_reference_files_mixed(self):
+        self.render_template('"file1", ("file2", "file3")')
+        assert self.the_bundle.contents == ('file1', 'file2', 'file3',)
+
     def test_reference_mixed(self):
         self.render_template('"foo_bundle", "file2", "file3"')
         assert self.the_bundle.contents == (self.foo_bundle, 'file2', 'file3',)
@@ -70,7 +84,7 @@ class TestTemplateTag(object):
         assert self.the_bundle.contents == (self.foo_bundle, 'a_file',)
 
     def test_output_urls(self):
-        """Ensure the tag correcly spits out the urls the bundle returns.
+        """Ensure the tag correctly spits out the urls the bundle returns.
         """
         self.BundleClass.urls_to_fake = ['foo', 'bar']
         assert self.render_template('"file1" "file2" "file3"') == 'foo;bar;'
@@ -80,3 +94,34 @@ class TestTemplateTag(object):
             '{% assets debug="True", "debug1.txt" %}{{ ASSET_URL }};{% endassets %}').render({})
         assert self.the_bundle.dbg == 'True'
 
+    def test_extra_values(self):
+        self.foo_bundle.extra = {'moo': 42}
+        output = self.jinja_env.from_string(
+            '{% assets "foo_bundle" %}{{ EXTRA.moo }}{% endassets %}').render()
+        assert output == '42'
+
+
+class TestLoader(TempEnvironmentHelper):
+
+    default_files = {
+        'template.html': """
+            <h1>Test</h1>
+            {% if foo %}
+                {% assets "A", "B", "C", output="output.html" %}
+                    {{ ASSET_URL }}
+                {% endassets %}
+            {% endif %}
+            """
+    }
+
+    def setup(self):
+        TempEnvironmentHelper.setup(self)
+        self.jinja_env = JinjaEnvironment()
+        self.jinja_env.add_extension(AssetsExtension)
+        self.jinja_env.assets_environment = self.env
+
+    def test(self):
+        loader = Jinja2Loader(self.env, [self.tempdir], [self.jinja_env])
+        bundles = loader.load_bundles()
+        assert len(bundles) == 1
+        assert bundles[0].output == "output.html"
